<?php

/**
 * Classe plxUpdater responsable du gestionnaire des mises  jour
 *
 * @package PLX
 * @author	Stephane F
 **/
 
define('PLX_UPDATE', PLX_ROOT.'update/');

class plxUpdater {

	public $newVersion = '';
	public $oldVersion = '' ;
	public $updateList = array(); # liste des mises  jour disponibles

	private $plxAdmin; # objet plxAdmin

	/**
	 * Constructeur de la classe plxUpdater
	 *
	 * @return	null
	 * @author	Stephane F
	 **/
	public function __construct() {

		$this->plxAdmin = new plxAdmin(PLX_CONF);

		$this->checkVersions();
		$this->getUpdateList();
	}

	/**
	 * Mthode qui charg de dmarrer les mises  jour
	 *
	 * @param	version		prcdente version de pluxml  mettre  jour, slectionner par l'utilisateur
	 * @return	null
	 * @author	Stphane F
	 **/
	public function start($version='') {
		if($this->update($version))
			$this->updateVersion();
	}

	/**
	 * Mthode qui recherche les n de version de pluxml
	 *
	 * @return	null
	 * @author	Stphane F
	 **/
	public function checkVersions() {

		# Rencherche ancien n de version de Pluxml  mettre  jour
		if(isset($this->plxAdmin->aConf['version']))
			$this->oldVersion = $this->plxAdmin->aConf['version'];

		# Nouvelle version de PluXml
		if(is_readable(PLX_ROOT.'version')) {
			$f = file(PLX_ROOT.'version');
			$this->newVersion = $f['0'];
		}
	}

	/**
	 * Mthode qui met  jour le n de version dans le fichier parametres.xml
	 *
	 * @return	null
	 * @author	Stphane F
	 **/
	public function updateVersion() {

		$new_params['version'] = $this->newVersion;
		$this->plxAdmin->editConfiguration($this->plxAdmin->aConf, $new_params);
		echo "Mise &agrave; jour de la version ".$this->newVersion.' termin&eacute;e.<br />';
	}

	/**
	 * Mthode qui rcupre la liste des mises  jour disponibles
	 *
	 * @return	null
	 * @author	Stphane F
	 **/
	public function getUpdateList() {

		$plxUpdates = plxGlob::getInstance(PLX_UPDATE);
		if($updates = $plxUpdates->query('/^update_[0-9\-\.]+.php$/')) {
			foreach($updates as $filename) {
				preg_match('/^(update_([0-9\-\.]+)).php$/', $filename, $capture);
				$this->updateList[$capture[2]] = array(
					'filename' 		=> $filename,
					'class_name'	=> str_replace('.', '_', $capture[1])
				);
			}
		}
		krsort($this->updateList);
	}

	/**
	 * Mthode qui execute les mises  jour tape par tape  partir des fichiers disponibles
	 *
	 * @return	null
	 * @author	Stphane F
	 **/
	public function update($version='') {

		$errors = false;
		foreach($this->updateList as $num_version => $update) {
			if(floatval($num_version) > floatval($this->oldVersion) AND floatval($num_version) > floatval($version)) {
				echo '<p><strong>Applications des mises &agrave jour version '.floatval($num_version).'</strong></p>';
				# inclusion du fichier de mise  jour
				include(PLX_UPDATE.$update['filename']);
				# cration d'un instance de l'objet de mise  jour
				$class_update = new $update['class_name']($this->plxAdmin); # cration d'une instance de l'objet de mise  jour
				# appel des diffrentes tapes de mise  jour
				$next = true;
				$step = 1;
				while($next AND !$errors) {
					$method_name = 'step'.$step;
					if(method_exists($update['class_name'], $method_name)) {
						if(!$class_update->$method_name($this->plxAdmin)) {
							$errors = true; # erreur dctecte
						} else {
							$step++; # tape suivante
							# on recharge l'objet plxAdmin pour prendre en compte les ventuels modifs de la mise  jour
							$this->plxAdmin = new plxAdmin(PLX_CONF);
						}
					}
					else $next = false;
				}
				echo '<br />';
			}
		}

		if($errors)
			echo '<p class="error">Une erreur s\'est produite pendant la mise &agrave; jour.</p>';
		else
			echo '<p class="msg">Toutes les mises &agrave; jour ont &eacute;t&eacute; appliqu&eacute;es avec succ&egrave;s !</p>';

		return !$errors;
	}

}

/**
 * Classe plxUpdate responsable d'executer des actions de mises  jour 
 *
 * @package PLX
 * @author	Stephane F
 **/
class plxUpdate {

	protected $plxAdmin; # objet de type plxAdmin

	/**
	 * Constructeur qui initialise l'objet plxAdmin par rfrence
	 *
	 * @return	null
	 * @author	Stephane F
	 **/
	public function __construct($plxAdmin) {
		$this->plxAdmin = &$plxAdmin;
	}

	/**
	 * Mthode qui met  jour le fichier parametre.xml en important les nouveaux paramtres 
	 *
	 * @param	new_params		tableau contenant la liste des nouveaux paramtres avec leur valeur par dfaut.
	 * @return	null
	 * @author	Stphane F
	 **/
	public function updateParameters($new_params) {

		$update_require = false;

		foreach($new_params as $k => $v)	{
			if(!isset($this->plxAdmin->aConf[$k]))
				$update_require = true;
			else
				$new_params[$k] = $this->plxAdmin->aConf[$k];
		}
		if($update_require) {
			return $this->plxAdmin->editConfiguration($this->plxAdmin->aConf, $new_params).'<br />';
		}

	}
}
?>